<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Products extends Controller {

    function __construct() {
            parent::Controller();
            $module_name = "shop";
            //$this->template->set('system_message', '');
            $this->load->model($this->config->item('shop_model'));
            $this->load->model($this->config->item('smp_model'));
            $this->lang->load('shop', 'english');
    }

    //---------------------------------------------------------------

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE PRODUCTS LIST PAGE">
    /*
     * Function: index
     * Description: Shows the products list page
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function index($offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'products/record',
            'View All'    =>  'products'
        );
        smp_set_page_meta('shop', 'product', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'product_name',
                'label'    =>  'Product Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            ) 
        );
        smp_create_form($search_form_fields, $this->config->item('form_product_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="FETCHING DATA">
        $where_additional = smp_form_where_clause($_POST, $this->config->item('tbl_products'));
        $total_records = smp_count($this->config->item('tbl_products'), $where_additional);
        $result_set['products'] = $this->Shop_model->get_products($offset, $this->config->item('records_per_page'), $where_additional);
        $pagination = smp_set_pagination($this->config->item('page_list_products'), $total_records);
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->set('resultset', $result_set['products']);
        $this->template->set('pagination', $pagination);
        $this->template->view($this->config->item('product_list_view'));
        //</editor-fold>
    }

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE PRODUCT VIEW/EDIT PAGE">
    /**
     * Function: record
     * Description: Shows the product  view/edit page
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function record($product_id = '', $offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'products/record',
            'View All'    =>  'products'
        );
        smp_set_page_meta('shop', 'product', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="FETCH FORM RULES & EXECUTE">
        $rules_config = smp_get_rules('products');
        $this->form_validation->set_rules($rules_config);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'product_name',
                'label'    =>  'Product Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_product_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="POPULATE THE FORM">
        if ($product_id): $where_additional = "product_id = " . $product_id; else: $where_additional = "product_id = 0"; endif;

        if ($this->input->post('action') && $this->form_validation->run()){
            //smp_process_form($_POST, $this->config->item('tbl_products'), 'product_id = ' . $product_id, 'shop/products');
            if (smp_action_permission($this->input->post('action'))) {
                $this->Shop_model->process_product($_POST, $this->input->post('action'), 'product_id = ' . $product_id, 'shop/products');
            }
        }
        $result_set = $this->Smp_model->get_records($this->config->item('tbl_products'), $where_additional, $offset, $this->config->item('records_per_page'));

        if ($result_set):
            foreach ($result_set as $value){
                /*  Create edit form */
                $product_form_fields = array(
                   array(
                         'field'    =>  'product_id',
                         'label'    =>  'Product ID',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  $value->product_id
                      ),
                   array(
                         'field'    =>  'product_type',
                         'label'    =>  'Product Type',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'PRODUCT_TYPE\' AND flg_enabled = \'Y\' '),
                         'selected' =>  $value->product_type
                      ),
                   array(
                         'field'    =>  'expire_download',
                         'label'    =>  'Expire Download In?',
                         'type'     =>  'text',
                         'class'    =>  '',
                         'custom'    =>  'size = 2',
                         'value'    =>  $value->expire_download,
                         'help'     =>  $this->lang->line('f_products_expire_download')
                      ),
                   array(
                         'field'    =>  'duration',
                         'label'    =>  'Subscription Term',
                         'type'     =>  'text',
                         'class'    =>  '',
                         'custom'    =>  'size = 2',
                         'value'    =>  $value->duration
                      ),
                   array(
                         'field'    =>  'duration_type',
                         'label'    =>  '',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'DURATION_TYPE\' AND flg_enabled = \'Y\' '),
                         'selected' =>  $value->duration_type
                      ),
                   array(
                         'field'    =>  'recurring_times',
                         'label'    =>  'Recurring Times',
                         'type'     =>  'text',
                         'class'    =>  '',
                         'custom'    =>  'size = 2',
                         'value'    =>  $value->recurring_times,
                         'help'     =>  $this->lang->line('f_products_recurring_times')
                      ),
                   /*array(
                         'field'    =>  'site_id',
                         'label'    =>  'Link to Site',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_sites'), 'site_id', 'site_title', ''),
                         'selected' =>  $value->site_id
                      ),
                    */
                   array(
                         'field'    =>  'product_name',
                         'label'    =>  'Product Title',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->product_name
                      ),
                   array(
                         'field'    =>  'description',
                         'label'    =>  'Description',
                         'type'     =>  'textarea',
                         'class'    =>  'small',
                         'value'    =>  $value->description
                      ),
                   array(
                         'field'    =>  'info_url',
                         'label'    =>  'Sales Page URL',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->info_url,
                         'help'     =>  $this->lang->line('f_products_info_url')
                      ),
                   array(
                         'field'    =>  'image_url',
                         'label'    =>  'Image URL',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->image_url,
                         'help'     =>  $this->lang->line('f_products_image_url')
                      ),
                   array(
                         'field'    =>  'price',
                         'label'    =>  'Price',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->price,
                         'help'     =>  $this->lang->line('f_products_price')
                      ),
                   array(
                         'field'    =>  'currency_code',
                         'label'    =>  'Currency',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_currency'), 'code', 'title', ''),
                         'selected' =>  $value->currency_code,
                         'help'     =>  $this->lang->line('f_products_currency_code')
                      ),
                   array(
                         'field'    =>  'template_id',
                         'label'    =>  'Order Page Template',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_templates'), 'template_id', 'template_title'),
                         'selected' =>  $value->template_id,
                         'help'     =>  $this->lang->line('f_products_template')
                      ),
                   array(
                         'field'    =>  'autoresponder_unit',
                         'label'    =>  'Autoresponder Address',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->autoresponder_unit,
                         'help'     =>  $this->lang->line('f_products_ar')
                      ),
                   array(
                         'field'    =>  'product_license',
                         'label'    =>  'Product License',
                         'type'     =>  'textarea',
                         'class'    =>  'medium',
                         'value'    =>  $value->product_license,
                         'help'     =>  $this->lang->line('f_products_license')
                      ),
                   array(
                         'field'    =>  'return_url',
                         'label'    =>  'Return URL After Purchase',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->return_url,
                         'help'     =>  $this->lang->line('f_products_return')
                      ),
                   array(
                         'field'    =>  'cancel_url',
                         'label'    =>  'Cancel URL',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->cancel_url,
                         'help'     =>  $this->lang->line('f_products_cancel')
                      ),
                   array(
                         'field'    =>  'gateways[]',
                         'label'    =>  'Payment Gateways',
                         'type'     =>  'multiselect',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_gateways'), 'gateway_id', 'title', '', false),
                         'selected' =>  $this->Shop_model->get_product_gateways($product_id),
                         'help'     =>  $this->lang->line('f_products_gateways')
                      ),
                    array(
                             'field'    =>  'flg_customer_area',
                             'label'    =>  'Display in Customer Area',
                             'type'     =>  'dropdown',
                             'class'    =>  'small',
                             'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                             'selected'    =>  $value->flg_customer_area,
                             'help'     =>  $this->lang->line('f_products_flg_customer_area')
                      ),
                    array(
                             'field'    =>  'flg_social_discussion',
                             'label'    =>  'Allow Social Discussion',
                             'type'     =>  'dropdown',
                             'class'    =>  'small',
                             'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                             'selected'    =>  $value->flg_social_discussion,
                             'help'     =>  $this->lang->line('f_products_flg_social_discussion')
                      ),
                   array(
                         'field'    =>  'cb_id',
                         'label'    =>  'Clickbank Product ID',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->cb_id,
                         'help'     =>  $this->lang->line('f_products_cb_id')
                      ),
                   array(
                         'field'    =>  'require_points',
                         'label'    =>  'Require Points',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->require_points,
                         'help'     =>  $this->lang->line('f_products_require_points')
                      ),
                   array(
                         'field'    =>  'award_points',
                         'label'    =>  'Award Points',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->award_points,
                         'help'     =>  $this->lang->line('f_products_award_points')
                      ),
                    array(
                         'field'    =>  'flg_enabled',
                         'label'    =>  'Enable This Product',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  $value->flg_enabled,
                         'help'     =>  $this->lang->line('f_products_flg_enabled')
                      ),
                   array(
                         'field'    =>  'product_download_page',
                         'label'    =>  'Download Information',
                         'type'     =>  'htmleditor',
                         'class'    =>  'collapsed',
                         'value'    =>  $value->product_download_page,
                         'help'     =>  $this->lang->line('f_products_download')
                      )

                );

                smp_create_form($product_form_fields, $this->config->item('form_product_record') . '/' . $product_id, 'form_record', 'perm_delete');
            }
        else:
            /*  Create view form */
            $product_form_fields = array(
               array(
                     'field'    =>  'product_type',
                     'label'    =>  'Product Type',
                     'type'     =>  'dropdown',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'PRODUCT_TYPE\' AND flg_enabled = \'Y\' '),
                     'selected' =>  ''
                  ),
               array(
                     'field'    =>  'expire_download',
                     'label'    =>  'Expire Download In?',
                     'type'     =>  'text',
                     'class'    =>  '',
                     'custom'    =>  'size = 2',
                     'value'    =>  '0',
                     'help'     =>  $this->lang->line('f_products_expire_download')
                  ),
               array(
                     'field'    =>  'duration',
                     'label'    =>  'Subscription Term',
                     'type'     =>  'text',
                     'class'    =>  '',
                     'custom'    =>  'size = 2',
                     'value'    =>  '0'
                  ),
               array(
                     'field'    =>  'duration_type',
                     'label'    =>  '',
                     'type'     =>  'dropdown',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'DURATION_TYPE\' AND flg_enabled = \'Y\' '),
                     'selected' =>  ''
                  ),
               array(
                     'field'    =>  'recurring_times',
                     'label'    =>  'Recurring Times',
                     'type'     =>  'text',
                     'class'    =>  '',
                     'custom'    =>  'size = 2',
                     'value'    =>  '0',
                     'help'     =>  $this->lang->line('f_products_recurring_times')
                  ),
               /*array(
                     'field'    =>  'site_id',
                     'label'    =>  'Link to Site',
                     'type'     =>  'dropdown',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_sites'), 'site_id', 'site_title', ''),
                     'selected' =>  'Test'
                  ),
                */
               array(
                     'field'    =>  'product_name',
                     'label'    =>  'Product Title',
                     'type'     =>  'text',
                     'class'    =>  'medium',
                     'value'    =>  ''
                  ),
               array(
                     'field'    =>  'description',
                     'label'    =>  'Description',
                     'type'     =>  'textarea',
                     'class'    =>  'small',
                     'value'    =>  ''
                  ),
               array(
                     'field'    =>  'info_url',
                     'label'    =>  'Sales Page URL',
                     'type'     =>  'text',
                     'class'    =>  'medium',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_info_url')
                  ),
               array(
                     'field'    =>  'image_url',
                     'label'    =>  'Image URL',
                     'type'     =>  'text',
                     'class'    =>  'medium',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_image_url')
                  ),
               array(
                     'field'    =>  'price',
                     'label'    =>  'Price',
                     'type'     =>  'text',
                     'class'    =>  'small',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_price')
                  ),
               array(
                     'field'    =>  'currency_code',
                     'label'    =>  'Currency',
                     'type'     =>  'dropdown',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_currency'), 'code', 'title', ''),
                     'selected' =>  '',
                     'help'     =>  $this->lang->line('f_products_currency_code')
                  ),
               array(
                     'field'    =>  'template_id',
                     'label'    =>  'Order Page Template',
                     'type'     =>  'dropdown',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_templates'), 'template_id', 'template_title'),
                     'selected' =>  '',
                     'help'     =>  $this->lang->line('f_products_template')
                  ),
               array(
                     'field'    =>  'autoresponder_unit',
                     'label'    =>  'Autoresponder Address',
                     'type'     =>  'text',
                     'class'    =>  'small',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_ar')
                  ),
               array(
                     'field'    =>  'product_license',
                     'label'    =>  'Product License',
                     'type'     =>  'textarea',
                     'class'    =>  'medium',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_license')
                  ),
               array(
                     'field'    =>  'return_url',
                     'label'    =>  'Return URL',
                     'type'     =>  'text',
                     'class'    =>  'medium',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_return')
                  ),
               array(
                     'field'    =>  'cancel_url',
                     'label'    =>  'Cancel URL',
                     'type'     =>  'text',
                     'class'    =>  'medium',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_cancel_return')
                  ),
               array(
                     'field'    =>  'gateways[]',
                     'label'    =>  'Payment Gateways',
                     'type'     =>  'multiselect',
                     'class'    =>  'small',
                     'value'    =>  get_options($this->config->item('tbl_gateways'), 'gateway_id', 'title', '', false),
                     'selected' =>  '',
                     'help'     =>  $this->lang->line('f_products_gateways')
                  ),
                array(
                         'field'    =>  'flg_customer_area',
                         'label'    =>  'Display in Customer Area',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  YES,
                         'help'     =>  $this->lang->line('f_products_flg_customer_area')
                  ),
                array(
                         'field'    =>  'flg_social_discussion',
                         'label'    =>  'Allow Social Discussion',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  YES,
                         'help'     =>  $this->lang->line('f_products_flg_social_discussion')
                  ),
                array(
                         'field'    =>  'cb_id',
                         'label'    =>  'Clickbank Product ID',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_products_cb_id')
                   ),
               array(
                     'field'    =>  'require_points',
                     'label'    =>  'Require Points',
                     'type'     =>  'text',
                     'class'    =>  'small',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_require_points')
                  ),
               array(
                     'field'    =>  'award_points',
                     'label'    =>  'Award Points',
                     'type'     =>  'text',
                     'class'    =>  'small',
                     'value'    =>  '',
                     'help'     =>  $this->lang->line('f_products_award_points')
                  ),
                array(
                         'field'    =>  'flg_enabled',
                         'label'    =>  'Enable This Product',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  '',
                         'help'     =>  $this->lang->line('f_products_flg_enabled')
                  ),
                array(
                         'field'    =>  'product_download_page',
                         'label'    =>  'Download Information',
                         'type'     =>  'htmleditor',
                         'class'    =>  'collapsed',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_products_download')
                  )
            );
            smp_create_form($product_form_fields, $this->config->item('form_product_record'), 'form_record', 'perm_add', 'plain');

        endif;
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->view($this->config->item('record_view'));
        //</editor-fold>
    }

     /**
     * Function: delete
     * Description: Deletes the Record
     * ##############################################################
     * Written: 05/01/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function delete($product_id = '')
    {
        //<editor-fold desc="DELETE RECORD">
        if (smp_check_permission($this->config->item('perm_delete'))){
            $this->Shop_model->process_product('', 'Delete', 'product_id = ' . $product_id, 'shop/products');
        }
        //</editor-fold>
    }

     /**
     * Function: duplicate
     * Description: Duplicates a Product
     * ##############################################################
     * Written: 03/05/2011
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function duplicate($product_id = '')
    {
        $sql = "INSERT INTO shop_products (sku, product_name, info_url, price, renewal_price, currency_code, image_url, description, shipping, add_shipping, file_path, file_path_type, product_type, account_id, product_header, product_footer, duration, duration_type, expire_download, product_download_page, kunaki_enabled, kunaki_product_id, autoresponder_service, autoresponder_unit, product_license, template_id, product_template, recurring_times, site_id, return_url, cancel_url, paypal_id, add_grp, remove_grp, flg_customer_area, stock, sold, flg_track_inventory, flg_social_discussion, cb_id, flg_enabled, r_cre_id, r_cre_time, r_mod_id, r_mod_time, require_points, award_points)
                SELECT sku, product_name, info_url, price, renewal_price, currency_code, image_url, description, shipping, add_shipping, file_path, file_path_type, product_type, account_id, product_header, product_footer, duration, duration_type, expire_download, product_download_page, kunaki_enabled, kunaki_product_id, autoresponder_service, autoresponder_unit, product_license, template_id, product_template, recurring_times, site_id, return_url, cancel_url, paypal_id, add_grp, remove_grp, flg_customer_area, stock, sold, flg_track_inventory, flg_social_discussion, cb_id, flg_enabled, r_cre_id, r_cre_time, r_mod_id, r_mod_time, require_points, award_points
                FROM shop_products
                WHERE product_id = " . $product_id ;
        smp_execute($sql);
        $new_product_id = $this->db->insert_id();
        $record_page = site_url('shop/products/record/' . $new_product_id);
        header('Location: ' . $record_page);

        //$this->Shop_model->process_product('', 'Duplicate', 'product_id = ' . $product_id, 'shop/products/record/');
    }

}

/* End of file products.php */
/* Location: ./app/controllers/shop/products.php */